pub fn memory() -> MemoryDriverExpand description
Convenience constructor for a memory driver.
The returned value can be passed directly to Store::builder().driver(...).
pub fn memory() -> MemoryDriverConvenience constructor for a memory driver.
The returned value can be passed directly to Store::builder().driver(...).