MemoryDriver

Struct MemoryDriver 

pub struct MemoryDriver { /* private fields */ }
In-process memory driver.

Implementations

Source

impl MemoryDriver

pub fn new() -> Self

Creates an empty memory driver.

pub fn len(&self) -> usize

Returns the number of records currently retained by the driver.

Expired records may still be retained until overwritten, deleted, or the driver is dropped.

pub fn is_empty(&self) -> bool

Returns true when no records are currently retained by the driver.

pub fn clear(&self)

Removes all retained records.